Module: AuditApi
- Defined in:
- lib/example_fdhbiopcnmeocbr_gem_misc/api_error.rb,
lib/example_fdhbiopcnmeocbr_gem_misc.rb,
lib/example_fdhbiopcnmeocbr_gem_misc/version.rb,
lib/example_fdhbiopcnmeocbr_gem_misc/api_client.rb,
lib/example_fdhbiopcnmeocbr_gem_misc/models/event.rb,
lib/example_fdhbiopcnmeocbr_gem_misc/configuration.rb,
lib/example_fdhbiopcnmeocbr_gem_misc/api/events_api.rb,
lib/example_fdhbiopcnmeocbr_gem_misc/models/headers.rb,
lib/example_fdhbiopcnmeocbr_gem_misc/models/request.rb,
lib/example_fdhbiopcnmeocbr_gem_misc/models/response.rb,
lib/example_fdhbiopcnmeocbr_gem_misc/models/user_info.rb,
lib/example_fdhbiopcnmeocbr_gem_misc/models/api_action.rb,
lib/example_fdhbiopcnmeocbr_gem_misc/models/api_action_all_of.rb
Overview
#Audit Log API
#The Audit Logs API lets you read audit log entries and track API calls or activities in the Bare Metal Cloud Portal.
Knowledge base articles to help you can be found here
All URLs are relative to (https://api.phoenixnap.com/audit/v1/)
The version of the OpenAPI document: 1.0 Contact: [email protected] Generated by: https://openapi-generator.tech OpenAPI Generator version: 5.4.0
Defined Under Namespace
Classes: ApiAction, ApiActionAllOf, ApiClient, ApiError, Configuration, Event, EventsApi, Headers, Request, Response, UserInfo
Constant Summary collapse
- VERSION =
get_version()
Class Method Summary collapse
-
.configure ⇒ Object
Customize default settings for the SDK using block.
Class Method Details
.configure ⇒ Object
Customize default settings for the SDK using block. AuditApi.configure do |config| config.username = "xxx" config.password = "xxx" end If no block given, return the default Configuration object.
39 40 41 42 43 44 45 |
# File 'lib/example_fdhbiopcnmeocbr_gem_misc.rb', line 39 def configure if block_given? yield(Configuration.default) else Configuration.default end end |